@@ -3,6 +3,7 @@ import logging
 import yaml
 
 from scanapi.config_loader import load_config_file
+from scanapi.console import write_results, write_summary
 from scanapi.errors import (
     BadConfigurationError,
     EmptyConfigFileError,
@@ -21,7 +22,6 @@ logger = logging.getLogger(__name__)
 def scan():
     """Caller function that tries to scans the file and write the report."""
     spec_path = settings["spec_path"]
-    no_report = settings["no_report"]
 
     try:
         api_spec = load_config_file(spec_path)
@@ -43,36 +43,50 @@ def scan():
         root_node = EndpointNode(api_spec)
         results = root_node.run()
 
-    except (InvalidKeyError, KeyError, InvalidPythonCodeError,) as e:
+    except (
+        InvalidKeyError,
+        KeyError,
+        InvalidPythonCodeError,
+    ) as e:
         error_message = "Error loading API spec."
         error_message = "{} {}".format(error_message, str(e))
         logger.error(error_message)
         raise SystemExit(ExitCode.USAGE_ERROR)
 
-    if no_report:
-        write_without_generating_report(results)
-    else:
-        try:
-            write_report(results)
-        except (BadConfigurationError, InvalidPythonCodeError) as e:
-            logger.error(e)
-            raise SystemExit(ExitCode.USAGE_ERROR)
-
+    _write(results)
+    write_summary()
     session.exit()
 
 
-def write_report(results):
+def _write(results):
+    """When the user passed the `--no-report` flag: prints the test results to
+    the console output.
+    When the user did not pass the `--no_report flag`: writes the results on a
+    report file and opens it using a browser, if the --browser flag is present.
+
+    Returns:
+        None
+    """
+    no_report = settings["no_report"]
+    open_browser = settings["open_browser"]
+
+    if no_report:
+        write_results(results)
+        return
+
+    try:
+        _write_report(results, open_browser)
+    except (BadConfigurationError, InvalidPythonCodeError) as e:
+        logger.error(e)
+        raise SystemExit(ExitCode.USAGE_ERROR)
+
+
+def _write_report(results, open_browser):
     """Constructs a Reporter object and calls the write method of Reporter to
     push the results to a file.
+
+    Returns:
+        None
     """
     reporter = Reporter(settings["output_path"], settings["template"])
-    reporter.write(results)
-
-
-def write_without_generating_report(results):
-    """Constructs a Reporter object and calls the
-    write_without_generating_report method of Reporter to print the results to
-    the console output without generating a report.
-    """
-    reporter = Reporter()
-    reporter.write_without_generating_report(results)
+    reporter.write(results, open_browser)
