@@ -1,9 +1,9 @@
-import logging
 import time
 
-from scanapi.errors import HTTPMethodNotAllowedError
-from scanapi.evaluators.spec_evaluator import SpecEvaluator  # noqa: F401
+from scanapi.console import console, write_result
+from scanapi.errors import HTTPMethodNotAllowedError, InvalidKeyError
 from scanapi.hide_utils import hide_sensitive_info
+from scanapi.settings import settings
 from scanapi.test_status import TestStatus
 from scanapi.tree.testing_node import TestingNode
 from scanapi.tree.tree_keys import (
@@ -12,6 +12,7 @@ from scanapi.tree.tree_keys import (
     HEADERS_KEY,
     METHOD_KEY,
     NAME_KEY,
+    OPTIONS_KEY,
     PARAMS_KEY,
     PATH_KEY,
     RETRY_KEY,
@@ -20,10 +21,17 @@ from scanapi.tree.tree_keys import (
 )
 from scanapi.utils import join_urls, session_with_retry, validate_keys
 
-logger = logging.getLogger(__name__)
-
 
 class RequestNode:
+    """
+    Class that represents a request. It's used as a child of an EndpointNode
+    where each EndpointNode may contain multiple children RequestNode.
+
+    Attributes:
+        spec[dict]: dictionary containing the request's specifications
+        endpoint[EndpointNode]: the parent node
+    """
+
     SCOPE = "request"
     ALLOWED_KEYS = (
         BODY_KEY,
@@ -36,7 +44,9 @@ class RequestNode:
         VARS_KEY,
         DELAY_KEY,
         RETRY_KEY,
+        OPTIONS_KEY,
     )
+    ALLOWED_OPTIONS = ("verify", "timeout")
     ALLOWED_HTTP_METHODS = (
         "GET",
         "POST",
@@ -77,21 +87,38 @@ class RequestNode:
         path = str(self.spec.get(PATH_KEY, ""))
         full_url = join_urls(base_path, path)
 
-        return self.endpoint.vars.evaluate(full_url)
+        self.endpoint.spec_vars.update(
+            self.spec.get(VARS_KEY, {}),
+            extras=dict(self.endpoint.spec_vars),
+            filter_responses=True,
+        )
+
+        return self.endpoint.spec_vars.evaluate(full_url)
+
+    @property
+    def options(self):
+        endpoint_options = self.endpoint.options
+        options = self.spec.get(OPTIONS_KEY, {})
+
+        for option in options:
+            if option not in self.ALLOWED_OPTIONS:
+                raise InvalidKeyError(option, OPTIONS_KEY, self.ALLOWED_OPTIONS)
+
+        return self.endpoint.spec_vars.evaluate({**endpoint_options, **options})
 
     @property
     def headers(self):
         endpoint_headers = self.endpoint.headers
         headers = self.spec.get(HEADERS_KEY, {})
 
-        return self.endpoint.vars.evaluate({**endpoint_headers, **headers})
+        return self.endpoint.spec_vars.evaluate({**endpoint_headers, **headers})
 
     @property
     def params(self):
         endpoint_params = self.endpoint.params
         params = self.spec.get(PARAMS_KEY, {})
 
-        return self.endpoint.vars.evaluate({**endpoint_params, **params})
+        return self.endpoint.spec_vars.evaluate({**endpoint_params, **params})
 
     @property
     def delay(self):
@@ -102,7 +129,7 @@ class RequestNode:
     def body(self):
         body = self.spec.get(BODY_KEY)
 
-        return self.endpoint.vars.evaluate(body)
+        return self.endpoint.spec_vars.evaluate(body)
 
     @property
     def tests(self):
@@ -126,13 +153,7 @@ class RequestNode:
 
         method = self.http_method
         url = self.full_url_path
-        logger.info("Making request %s %s", method, url)
-
-        self.endpoint.vars.update(
-            self.spec.get(VARS_KEY, {}),
-            extras=dict(self.endpoint.vars),
-            filter_responses=True,
-        )
+        console.print(f"\n- Making request {method} {url}", highlight=False)
 
         session = session_with_retry(self.retry)
         response = session.request(
@@ -142,21 +163,23 @@ class RequestNode:
             params=self.params,
             json=self.body,
             allow_redirects=False,
+            **self.options,
         )
 
-        extras = dict(self.endpoint.vars)
+        extras = dict(self.endpoint.spec_vars)
         extras["response"] = response
 
-        self.endpoint.vars.update(
-            self.spec.get(VARS_KEY, {}), extras=extras,
+        self.endpoint.spec_vars.update(
+            self.spec.get(VARS_KEY, {}),
+            extras=extras,
         )
 
         tests_results = self._run_tests()
         hide_sensitive_info(response)
 
-        del self.endpoint.vars["response"]
+        del self.endpoint.spec_vars["response"]
 
-        return {
+        result = {
             "response": response,
             "tests_results": tests_results,
             "no_failure": all(
@@ -164,8 +187,14 @@ class RequestNode:
                 for test_result in tests_results
             ),
             "request_node_name": self.name,
+            "options": self.options,
         }
 
+        if not settings["no_report"]:
+            write_result(result)
+
+        return result
+
     def _run_tests(self):
         """Run all tests cases of request node.
 
